@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet
-     Copyright (C) 2006, 2009, 2010, 2012, 2015, 2017, 2018 GNUnet e.V.
+     Copyright (C) 2006, 2009, 2010, 2012, 2015, 2017, 2018, 2022 GNUnet e.V.
 
      GNUnet is free software: you can redistribute it and/or modify it
      under the terms of the GNU Affero General Public License as published
@@ -67,7 +67,8 @@ static int
 init_connection (struct Plugin *plugin)
 {
   struct GNUNET_PQ_ExecuteStatement es[] = {
-    GNUNET_PQ_make_try_execute ("CREATE TEMPORARY SEQUENCE IF NOT EXISTS gn011dc_oid_seq"),
+    GNUNET_PQ_make_try_execute (
+      "CREATE TEMPORARY SEQUENCE IF NOT EXISTS gn011dc_oid_seq"),
     GNUNET_PQ_make_execute ("CREATE TEMPORARY TABLE IF NOT EXISTS gn011dc ("
                             "  oid OID NOT NULL DEFAULT nextval('gn011dc_oid_seq'),"
                             "  type INTEGER NOT NULL,"
@@ -107,15 +108,21 @@ init_connection (struct Plugin *plugin)
                             "SELECT length(value) AS len,oid,key FROM gn011dc"
                             " ORDER BY prox ASC, discard_time ASC LIMIT 1",
                             0),
-    GNUNET_PQ_make_prepare ("get_random",
-                            "SELECT discard_time,type,value,path,key FROM gn011dc"
-                            " WHERE discard_time >= $1"
-                            " ORDER BY key ASC LIMIT 1 OFFSET $2",
-                            2),
     GNUNET_PQ_make_prepare ("get_closest",
-                            "SELECT discard_time,type,value,path,key FROM gn011dc "
-                            "WHERE key>=$1 AND discard_time >= $2 ORDER BY key ASC LIMIT $3",
-                            3),
+                            "(SELECT discard_time,type,value,path,key FROM gn011dc"
+                            " WHERE key >= $1"
+                            "   AND discard_time >= $2"
+                            "   AND ( (type = $3) OR ( 0 = $3) )"
+                            " ORDER BY key ASC"
+                            " LIMIT $4)"
+                            " UNION "
+                            "(SELECT discard_time,type,value,path,key FROM gn011dc"
+                            " WHERE key <= $1"
+                            "   AND discard_time >= $2"
+                            "   AND ( (type = $3) OR ( 0 = $3) )"
+                            " ORDER BY key DESC"
+                            " LIMIT $4)",
+                            4),
     GNUNET_PQ_make_prepare ("delrow",
                             "DELETE FROM gn011dc WHERE oid=$1",
                             1),
@@ -160,7 +167,7 @@ postgres_plugin_put (void *cls,
                      enum GNUNET_BLOCK_Type type,
                      struct GNUNET_TIME_Absolute discard_time,
                      unsigned int path_info_len,
-                     const struct GNUNET_PeerIdentity *path_info)
+                     const struct GNUNET_DHT_PathElement *path_info)
 {
   struct Plugin *plugin = cls;
   uint32_t type32 = (uint32_t) type;
@@ -172,7 +179,7 @@ postgres_plugin_put (void *cls,
     GNUNET_PQ_query_param_fixed_size (data, data_size),
     GNUNET_PQ_query_param_fixed_size (path_info,
                                       path_info_len * sizeof(struct
-                                                             GNUNET_PeerIdentity)),
+                                                             GNUNET_DHT_PathElement)),
     GNUNET_PQ_query_param_end
   };
   enum GNUNET_DB_QueryStatus ret;
@@ -231,7 +238,7 @@ handle_results (void *cls,
     uint32_t type;
     void *data;
     size_t data_size;
-    struct GNUNET_PeerIdentity *path;
+    struct GNUNET_DHT_PathElement *path;
     size_t path_len;
     struct GNUNET_PQ_ResultSpec rs[] = {
       GNUNET_PQ_result_spec_absolute_time ("discard_time",
@@ -255,12 +262,12 @@ handle_results (void *cls,
       GNUNET_break (0);
       return;
     }
-    if (0 != (path_len % sizeof(struct GNUNET_PeerIdentity)))
+    if (0 != (path_len % sizeof(struct GNUNET_DHT_PathElement)))
     {
       GNUNET_break (0);
       path_len = 0;
     }
-    path_len %= sizeof(struct GNUNET_PeerIdentity);
+    path_len %= sizeof(struct GNUNET_DHT_PathElement);
     LOG (GNUNET_ERROR_TYPE_DEBUG,
          "Found result of size %u bytes and type %u in database\n",
          (unsigned int) data_size,
@@ -409,96 +416,6 @@ postgres_plugin_del (void *cls)
 }
 
 
-/**
- * Obtain a random key-value pair from the datacache.
- *
- * @param cls closure (our `struct Plugin`)
- * @param iter maybe NULL (to just count)
- * @param iter_cls closure for @a iter
- * @return the number of results found, zero (datacache empty) or one
- */
-static unsigned int
-postgres_plugin_get_random (void *cls,
-                            GNUNET_DATACACHE_Iterator iter,
-                            void *iter_cls)
-{
-  struct Plugin *plugin = cls;
-  uint32_t off;
-  struct GNUNET_TIME_Absolute now = { 0 };
-  struct GNUNET_TIME_Absolute expiration_time;
-  size_t data_size;
-  void *data;
-  size_t path_len;
-  struct GNUNET_PeerIdentity *path;
-  struct GNUNET_HashCode key;
-  uint32_t type;
-  enum GNUNET_DB_QueryStatus res;
-  struct GNUNET_PQ_QueryParam params[] = {
-    GNUNET_PQ_query_param_absolute_time (&now),
-    GNUNET_PQ_query_param_uint32 (&off),
-    GNUNET_PQ_query_param_end
-  };
-  struct GNUNET_PQ_ResultSpec rs[] = {
-    GNUNET_PQ_result_spec_absolute_time ("discard_time",
-                                         &expiration_time),
-    GNUNET_PQ_result_spec_uint32 ("type",
-                                  &type),
-    GNUNET_PQ_result_spec_variable_size ("value",
-                                         &data,
-                                         &data_size),
-    GNUNET_PQ_result_spec_variable_size ("path",
-                                         (void **) &path,
-                                         &path_len),
-    GNUNET_PQ_result_spec_auto_from_type ("key",
-                                          &key),
-    GNUNET_PQ_result_spec_end
-  };
-
-  if (0 == plugin->num_items)
-    return 0;
-  if (NULL == iter)
-    return 1;
-  now = GNUNET_TIME_absolute_get ();
-  off = GNUNET_CRYPTO_random_u32 (GNUNET_CRYPTO_QUALITY_NONCE,
-                                  plugin->num_items);
-  res = GNUNET_PQ_eval_prepared_singleton_select (plugin->dbh,
-                                                  "get_random",
-                                                  params,
-                                                  rs);
-  if (0 > res)
-  {
-    GNUNET_break (0);
-    return 0;
-  }
-  if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == res)
-  {
-    GNUNET_break (0);
-    return 0;
-  }
-  if (0 != (path_len % sizeof(struct GNUNET_PeerIdentity)))
-  {
-    GNUNET_break (0);
-    path_len = 0;
-  }
-  path_len %= sizeof(struct GNUNET_PeerIdentity);
-  LOG (GNUNET_ERROR_TYPE_DEBUG,
-       "Found random value with key %s of size %u bytes and type %u in database\n",
-       GNUNET_h2s (&key),
-       (unsigned int) data_size,
-       (unsigned int) type);
-  (void) iter (iter_cls,
-               &key,
-               data_size,
-               data,
-               (enum GNUNET_BLOCK_Type) type,
-               expiration_time,
-               path_len,
-               path);
-  GNUNET_PQ_cleanup_result (rs);
-  return 1;
-}
-
-
 /**
  * Closure for #extract_result_cb.
  */
@@ -540,7 +457,7 @@ extract_result_cb (void *cls,
     uint32_t type;
     void *data;
     size_t data_size;
-    struct GNUNET_PeerIdentity *path;
+    struct GNUNET_DHT_PathElement *path;
     size_t path_len;
     struct GNUNET_HashCode key;
     struct GNUNET_PQ_ResultSpec rs[] = {
@@ -567,12 +484,12 @@ extract_result_cb (void *cls,
       GNUNET_break (0);
       return;
     }
-    if (0 != (path_len % sizeof(struct GNUNET_PeerIdentity)))
+    if (0 != (path_len % sizeof(struct GNUNET_DHT_PathElement)))
     {
       GNUNET_break (0);
       path_len = 0;
     }
-    path_len %= sizeof(struct GNUNET_PeerIdentity);
+    path_len %= sizeof(struct GNUNET_DHT_PathElement);
     LOG (GNUNET_ERROR_TYPE_DEBUG,
          "Found result of size %u bytes and type %u in database\n",
          (unsigned int) data_size,
@@ -605,6 +522,7 @@ extract_result_cb (void *cls,
  *
  * @param cls closure (internal context for the plugin)
  * @param key area of the keyspace to look into
+ * @param type desired block type for the replies
  * @param num_results number of results that should be returned to @a iter
  * @param iter maybe NULL (to just count)
  * @param iter_cls closure for @a iter
@@ -613,16 +531,19 @@ extract_result_cb (void *cls,
 static unsigned int
 postgres_plugin_get_closest (void *cls,
                              const struct GNUNET_HashCode *key,
+                             enum GNUNET_BLOCK_Type type,
                              unsigned int num_results,
                              GNUNET_DATACACHE_Iterator iter,
                              void *iter_cls)
 {
   struct Plugin *plugin = cls;
   uint32_t num_results32 = (uint32_t) num_results;
+  uint32_t type32 = (uint32_t) type;
   struct GNUNET_TIME_Absolute now;
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_auto_from_type (key),
     GNUNET_PQ_query_param_absolute_time (&now),
+    GNUNET_PQ_query_param_uint32 (&type32),
     GNUNET_PQ_query_param_uint32 (&num_results32),
     GNUNET_PQ_query_param_end
   };
@@ -681,7 +602,6 @@ libgnunet_plugin_datacache_postgres_init (void *cls)
   api->get = &postgres_plugin_get;
   api->put = &postgres_plugin_put;
   api->del = &postgres_plugin_del;
-  api->get_random = &postgres_plugin_get_random;
   api->get_closest = &postgres_plugin_get_closest;
   LOG (GNUNET_ERROR_TYPE_INFO,
        "Postgres datacache running\n");
