@@ -137,7 +137,7 @@ get_callback (void *cls,
               uint32_t hop_count,
               uint32_t desired_replication_level,
               unsigned int path_length,
-              const struct GNUNET_PeerIdentity *path,
+              const struct GNUNET_DHT_PathElement *path,
               const struct GNUNET_HashCode *key)
 {
   fprintf (stdout,
@@ -166,9 +166,9 @@ get_callback (void *cls,
 static void
 get_resp_callback (void *cls,
                    enum GNUNET_BLOCK_Type type,
-                   const struct GNUNET_PeerIdentity *get_path,
+                   const struct GNUNET_DHT_PathElement *get_path,
                    unsigned int get_path_length,
-                   const struct GNUNET_PeerIdentity *put_path,
+                   const struct GNUNET_DHT_PathElement *put_path,
                    unsigned int put_path_length,
                    struct GNUNET_TIME_Absolute exp,
                    const struct GNUNET_HashCode *key,
@@ -211,7 +211,7 @@ put_callback (void *cls,
               uint32_t hop_count,
               uint32_t desired_replication_level,
               unsigned int path_length,
-              const struct GNUNET_PeerIdentity *path,
+              const struct GNUNET_DHT_PathElement *path,
               struct GNUNET_TIME_Absolute exp,
               const struct GNUNET_HashCode *key,
               const void *data,
