@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet
-     Copyright (C) 2006, 2011 GNUnet e.V.
+     Copyright (C) 2006, 2011, 2020 GNUnet e.V.
 
      GNUnet is free software: you can redistribute it and/or modify it
      under the terms of the GNU Affero General Public License as published
@@ -38,7 +38,7 @@
  * @param value not used (NULL)
  * @return #GNUNET_NO (do not continue, not an error)
  */
-static int
+static enum GNUNET_GenericReturnValue
 print_version (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
                void *scls,
                const char *option,
@@ -53,22 +53,18 @@ print_version (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
 }
 
 
-/**
- * Define the option to print the version of
- * the application (-v option)
- *
- * @param version string with the version number
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_version (const char *version)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo = { .shortName = 'v',
-                                                 .name = "version",
-                                                 .description = gettext_noop (
-                                                   "print the version number"),
-                                                 .option_exclusive = 1,
-                                                 .processor = &print_version,
-                                                 .scls = (void *) version };
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = 'v',
+    .name = "version",
+    .description = gettext_noop (
+      "print the version number"),
+    .option_exclusive = 1,
+    .processor = &print_version,
+    .scls = (void *) version
+  };
 
   return clo;
 }
@@ -88,7 +84,7 @@ GNUNET_GETOPT_option_version (const char *version)
  * @param value not used (NULL)
  * @return #GNUNET_NO (do not continue, not an error)
  */
-static int
+static enum GNUNET_GenericReturnValue
 format_help (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
              void *scls,
              const char *option,
@@ -178,7 +174,8 @@ OUTER:
     i++;
   }
   pd = GNUNET_OS_project_data_get ();
-  printf ("Report bugs to %s.\n"
+  printf ("\n"
+          "Report bugs to %s.\n"
           "Home page: %s\n",
           pd->bug_email,
           pd->homepage);
@@ -190,22 +187,18 @@ OUTER:
 }
 
 
-/**
- * Defining the option to print the command line
- * help text (-h option).
- *
- * @param about string with brief description of the application
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_help (const char *about)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo = { .shortName = 'h',
-                                                 .name = "help",
-                                                 .description = gettext_noop (
-                                                   "print this help"),
-                                                 .option_exclusive = 1,
-                                                 .processor = format_help,
-                                                 .scls = (void *) about };
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = 'h',
+    .name = "help",
+    .description = gettext_noop (
+      "print this help"),
+    .option_exclusive = 1,
+    .processor = format_help,
+    .scls = (void *) about
+  };
 
   return clo;
 }
@@ -225,7 +218,7 @@ GNUNET_GETOPT_option_help (const char *about)
  * @param value not used (NULL)
  * @return #GNUNET_OK
  */
-static int
+static enum GNUNET_GenericReturnValue
 increment_value (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
                  void *scls,
                  const char *option,
@@ -241,46 +234,35 @@ increment_value (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
 }
 
 
-/**
- * Increment @a val each time the option flag is given by one.
- *
- * @param shortName short name of the option
- * @param name long name of the option
- * @param argumentHelp help text for the option argument
- * @param description long help text for the option
- * @param[out] val increment by 1 each time the option is present
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_increment_uint (char shortName,
                                      const char *name,
                                      const char *description,
                                      unsigned int *val)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo = { .shortName = shortName,
-                                                 .name = name,
-                                                 .description = description,
-                                                 .processor = &increment_value,
-                                                 .scls = (void *) val };
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = shortName,
+    .name = name,
+    .description = description,
+    .processor = &increment_value,
+    .scls = (void *) val
+  };
 
   return clo;
 }
 
 
-/**
- * Define the '-V' verbosity option.  Using the option more
- * than once increments @a level each time.
- *
- * @param[out] level set to the verbosity level
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_verbose (unsigned int *level)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo = { .shortName = 'V',
-                                                 .name = "verbose",
-                                                 .description =
-                                                   gettext_noop ("be verbose"),
-                                                 .processor = &increment_value,
-                                                 .scls = (void *) level };
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = 'V',
+    .name = "verbose",
+    .description =
+      gettext_noop ("be verbose"),
+    .processor = &increment_value,
+    .scls = (void *) level
+  };
 
   return clo;
 }
@@ -300,7 +282,7 @@ GNUNET_GETOPT_option_verbose (unsigned int *level)
  * @param value not used (NULL)
  * @return #GNUNET_OK
  */
-static int
+static enum GNUNET_GenericReturnValue
 set_one (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
          void *scls,
          const char *option,
@@ -316,27 +298,19 @@ set_one (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
 }
 
 
-/**
- * Allow user to specify a flag (which internally means setting
- * an integer to 1/#GNUNET_YES/#GNUNET_OK.
- *
- * @param shortName short name of the option
- * @param name long name of the option
- * @param argumentHelp help text for the option argument
- * @param description long help text for the option
- * @param[out] val set to 1 if the option is present
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_flag (char shortName,
                            const char *name,
                            const char *description,
                            int *val)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo = { .shortName = shortName,
-                                                 .name = name,
-                                                 .description = description,
-                                                 .processor = &set_one,
-                                                 .scls = (void *) val };
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = shortName,
+    .name = name,
+    .description = description,
+    .processor = &set_one,
+    .scls = (void *) val
+  };
 
   return clo;
 }
@@ -356,7 +330,7 @@ GNUNET_GETOPT_option_flag (char shortName,
  * @param value actual value of the option (a string)
  * @return #GNUNET_OK
  */
-static int
+static enum GNUNET_GenericReturnValue
 set_string (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
             void *scls,
             const char *option,
@@ -367,21 +341,12 @@ set_string (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
   (void) ctx;
   (void) option;
   GNUNET_assert (NULL != value);
-  GNUNET_free_non_null (*val);
+  GNUNET_free (*val);
   *val = GNUNET_strdup (value);
   return GNUNET_OK;
 }
 
 
-/**
- * Allow user to specify a string.
- *
- * @param shortName short name of the option
- * @param name long name of the option
- * @param argumentHelp help text for the option argument
- * @param description long help text for the option
- * @param[out] str set to the string
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_string (char shortName,
                              const char *name,
@@ -389,35 +354,32 @@ GNUNET_GETOPT_option_string (char shortName,
                              const char *description,
                              char **str)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo = { .shortName = shortName,
-                                                 .name = name,
-                                                 .argumentHelp = argumentHelp,
-                                                 .description = description,
-                                                 .require_argument = 1,
-                                                 .processor = &set_string,
-                                                 .scls = (void *) str };
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = shortName,
+    .name = name,
+    .argumentHelp = argumentHelp,
+    .description = description,
+    .require_argument = 1,
+    .processor = &set_string,
+    .scls = (void *) str
+  };
 
   return clo;
 }
 
 
-/**
- * Define the '-L' log level option.  Note that we do not check
- * that the log level is valid here.
- *
- * @param[out] level set to the log level
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_loglevel (char **level)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo =
-  { .shortName = 'L',
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = 'L',
     .name = "log",
     .argumentHelp = "LOGLEVEL",
     .description = gettext_noop ("configure logging to use LOGLEVEL"),
     .require_argument = 1,
     .processor = &set_string,
-    .scls = (void *) level };
+    .scls = (void *) level
+  };
 
   return clo;
 }
@@ -434,7 +396,7 @@ GNUNET_GETOPT_option_loglevel (char **level)
  * @param value actual value of the option (a string)
  * @return #GNUNET_OK
  */
-static int
+static enum GNUNET_GenericReturnValue
 set_filename (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
               void *scls,
               const char *option,
@@ -445,21 +407,12 @@ set_filename (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
   (void) ctx;
   (void) option;
   GNUNET_assert (NULL != value);
-  GNUNET_free_non_null (*val);
+  GNUNET_free (*val);
   *val = GNUNET_STRINGS_filename_expand (value);
   return GNUNET_OK;
 }
 
 
-/**
- * Allow user to specify a filename (automatically path expanded).
- *
- * @param shortName short name of the option
- * @param name long name of the option
- * @param argumentHelp help text for the option argument
- * @param description long help text for the option
- * @param[out] str set to the string
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_filename (char shortName,
                                const char *name,
@@ -467,56 +420,50 @@ GNUNET_GETOPT_option_filename (char shortName,
                                const char *description,
                                char **str)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo = { .shortName = shortName,
-                                                 .name = name,
-                                                 .argumentHelp = argumentHelp,
-                                                 .description = description,
-                                                 .require_argument = 1,
-                                                 .processor = &set_filename,
-                                                 .scls = (void *) str };
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = shortName,
+    .name = name,
+    .argumentHelp = argumentHelp,
+    .description = description,
+    .require_argument = 1,
+    .processor = &set_filename,
+    .scls = (void *) str
+  };
 
   return clo;
 }
 
 
-/**
- * Allow user to specify log file name (-l option)
- *
- * @param[out] logfn set to the name of the logfile
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_logfile (char **logfn)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo =
-  { .shortName = 'l',
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = 'l',
     .name = "logfile",
     .argumentHelp = "FILENAME",
     .description =
       gettext_noop ("configure logging to write logs to FILENAME"),
     .require_argument = 1,
     .processor = &set_filename,
-    .scls = (void *) logfn };
+    .scls = (void *) logfn
+  };
 
   return clo;
 }
 
 
-/**
- * Allow user to specify configuration file name (-c option)
- *
- * @param[out] fn set to the name of the configuration file
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_cfgfile (char **fn)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo =
-  { .shortName = 'c',
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = 'c',
     .name = "config",
     .argumentHelp = "FILENAME",
     .description = gettext_noop ("use configuration file FILENAME"),
     .require_argument = 1,
     .processor = &set_filename,
-    .scls = (void *) fn };
+    .scls = (void *) fn
+  };
 
   return clo;
 }
@@ -535,7 +482,7 @@ GNUNET_GETOPT_option_cfgfile (char **fn)
  * @param value actual value of the option as a string.
  * @return #GNUNET_OK if parsing the value worked
  */
-static int
+static enum GNUNET_GenericReturnValue
 set_ulong (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
            void *scls,
            const char *option,
@@ -556,15 +503,6 @@ set_ulong (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
 }
 
 
-/**
- * Allow user to specify an `unsigned long long`
- *
- * @param shortName short name of the option
- * @param name long name of the option
- * @param argumentHelp help text for the option argument
- * @param description long help text for the option
- * @param[out] val set to the value specified at the command line
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_ulong (char shortName,
                             const char *name,
@@ -572,13 +510,15 @@ GNUNET_GETOPT_option_ulong (char shortName,
                             const char *description,
                             unsigned long long *val)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo = { .shortName = shortName,
-                                                 .name = name,
-                                                 .argumentHelp = argumentHelp,
-                                                 .description = description,
-                                                 .require_argument = 1,
-                                                 .processor = &set_ulong,
-                                                 .scls = (void *) val };
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = shortName,
+    .name = name,
+    .argumentHelp = argumentHelp,
+    .description = description,
+    .require_argument = 1,
+    .processor = &set_ulong,
+    .scls = (void *) val
+  };
 
   return clo;
 }
@@ -597,7 +537,86 @@ GNUNET_GETOPT_option_ulong (char shortName,
  * @param value actual value of the option as a string.
  * @return #GNUNET_OK if parsing the value worked
  */
-static int
+static enum GNUNET_GenericReturnValue
+set_timetravel_time (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
+                     void *scls,
+                     const char *option,
+                     const char *value)
+{
+  long long delta;
+  long long minus;
+  struct GNUNET_TIME_Relative rt;
+
+  (void) scls;
+  (void) ctx;
+  while (isspace (value[0]))
+    value++;
+  minus = 1;
+  if (value[0] == '-')
+  {
+    minus = -1;
+    value++;
+  }
+  else if (value[0] == '+')
+  {
+    value++;
+  }
+  if (GNUNET_OK !=
+      GNUNET_STRINGS_fancy_time_to_relative (value,
+                                             &rt))
+  {
+    fprintf (stderr,
+             _ (
+               "You must pass a relative time (optionally with sign) to the `%s' option.\n"),
+             option);
+    return GNUNET_SYSERR;
+  }
+  if (rt.rel_value_us > LLONG_MAX)
+  {
+    fprintf (stderr,
+             _ ("Value given for time travel `%s' option is too big.\n"),
+             option);
+    return GNUNET_SYSERR;
+  }
+  delta = (long long) rt.rel_value_us;
+  delta *= minus;
+  GNUNET_TIME_set_offset (delta);
+  return GNUNET_OK;
+}
+
+
+struct GNUNET_GETOPT_CommandLineOption
+GNUNET_GETOPT_option_timetravel (char shortName,
+                                 const char *name)
+{
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = shortName,
+    .name = name,
+    .argumentHelp = _ ("[+/-]MICROSECONDS"),
+    .description = _ (
+      "modify system time by given offset (for debugging/testing only)"),
+    .require_argument = 1,
+    .processor = &set_timetravel_time
+  };
+
+  return clo;
+}
+
+
+/**
+ * Set an option of type 'struct GNUNET_TIME_Relative' from the command line.
+ * A pointer to this function should be passed as part of the
+ * 'struct GNUNET_GETOPT_CommandLineOption' array to initialize options
+ * of this type.  It should be followed by a pointer to a value of
+ * type 'struct GNUNET_TIME_Relative'.
+ *
+ * @param ctx command line processing context
+ * @param scls additional closure (will point to the 'struct GNUNET_TIME_Relative')
+ * @param option name of the option
+ * @param value actual value of the option as a string.
+ * @return #GNUNET_OK if parsing the value worked
+ */
+static enum GNUNET_GenericReturnValue
 set_relative_time (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
                    void *scls,
                    const char *option,
@@ -617,16 +636,6 @@ set_relative_time (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
 }
 
 
-/**
- * Allow user to specify a `struct GNUNET_TIME_Relative`
- * (using human-readable "fancy" time).
- *
- * @param shortName short name of the option
- * @param name long name of the option
- * @param argumentHelp help text for the option argument
- * @param description long help text for the option
- * @param[out] val set to the time specified at the command line
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_relative_time (char shortName,
                                     const char *name,
@@ -634,14 +643,15 @@ GNUNET_GETOPT_option_relative_time (char shortName,
                                     const char *description,
                                     struct GNUNET_TIME_Relative *val)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo = { .shortName = shortName,
-                                                 .name = name,
-                                                 .argumentHelp = argumentHelp,
-                                                 .description = description,
-                                                 .require_argument = 1,
-                                                 .processor =
-                                                   &set_relative_time,
-                                                 .scls = (void *) val };
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = shortName,
+    .name = name,
+    .argumentHelp = argumentHelp,
+    .description = description,
+    .require_argument = 1,
+    .processor = &set_relative_time,
+    .scls = (void *) val
+  };
 
   return clo;
 }
@@ -660,7 +670,7 @@ GNUNET_GETOPT_option_relative_time (char shortName,
  * @param value actual value of the option as a string.
  * @return #GNUNET_OK if parsing the value worked
  */
-static int
+static enum GNUNET_GenericReturnValue
 set_absolute_time (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
                    void *scls,
                    const char *option,
@@ -680,16 +690,6 @@ set_absolute_time (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
 }
 
 
-/**
- * Allow user to specify a `struct GNUNET_TIME_Absolute`
- * (using human-readable "fancy" time).
- *
- * @param shortName short name of the option
- * @param name long name of the option
- * @param argumentHelp help text for the option argument
- * @param description long help text for the option
- * @param[out] val set to the time specified at the command line
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_absolute_time (char shortName,
                                     const char *name,
@@ -697,14 +697,79 @@ GNUNET_GETOPT_option_absolute_time (char shortName,
                                     const char *description,
                                     struct GNUNET_TIME_Absolute *val)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo = { .shortName = shortName,
-                                                 .name = name,
-                                                 .argumentHelp = argumentHelp,
-                                                 .description = description,
-                                                 .require_argument = 1,
-                                                 .processor =
-                                                   &set_absolute_time,
-                                                 .scls = (void *) val };
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = shortName,
+    .name = name,
+    .argumentHelp = argumentHelp,
+    .description = description,
+    .require_argument = 1,
+    .processor = &set_absolute_time,
+    .scls = (void *) val
+  };
+
+  return clo;
+}
+
+
+/**
+ * Set an option of type 'struct GNUNET_TIME_Timestamp' from the command line.
+ * A pointer to this function should be passed as part of the
+ * 'struct GNUNET_GETOPT_CommandLineOption' array to initialize options
+ * of this type.  It should be followed by a pointer to a value of
+ * type 'struct GNUNET_TIME_Absolute'.
+ *
+ * @param ctx command line processing context
+ * @param scls additional closure (will point to the `struct GNUNET_TIME_Absolute`)
+ * @param option name of the option
+ * @param value actual value of the option as a string.
+ * @return #GNUNET_OK if parsing the value worked
+ */
+static enum GNUNET_GenericReturnValue
+set_timestamp (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
+               void *scls,
+               const char *option,
+               const char *value)
+{
+  struct GNUNET_TIME_Timestamp *t = scls;
+  struct GNUNET_TIME_Absolute abs;
+
+  (void) ctx;
+  if (GNUNET_OK !=
+      GNUNET_STRINGS_fancy_time_to_absolute (value,
+                                             &abs))
+  {
+    fprintf (stderr,
+             _ ("You must pass a timestamp to the `%s' option.\n"),
+             option);
+    return GNUNET_SYSERR;
+  }
+  if (0 != abs.abs_value_us % GNUNET_TIME_UNIT_SECONDS.rel_value_us)
+  {
+    fprintf (stderr,
+             _ ("The maximum precision allowed for timestamps is seconds.\n"));
+    return GNUNET_SYSERR;
+  }
+  t->abs_time = abs;
+  return GNUNET_OK;
+}
+
+
+struct GNUNET_GETOPT_CommandLineOption
+GNUNET_GETOPT_option_timestamp (char shortName,
+                                const char *name,
+                                const char *argumentHelp,
+                                const char *description,
+                                struct GNUNET_TIME_Timestamp *val)
+{
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = shortName,
+    .name = name,
+    .argumentHelp = argumentHelp,
+    .description = description,
+    .require_argument = 1,
+    .processor = &set_timestamp,
+    .scls = (void *) val
+  };
 
   return clo;
 }
@@ -723,7 +788,7 @@ GNUNET_GETOPT_option_absolute_time (char shortName,
  * @param value actual value of the option as a string.
  * @return #GNUNET_OK if parsing the value worked
  */
-static int
+static enum GNUNET_GenericReturnValue
 set_uint (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
           void *scls,
           const char *option,
@@ -737,7 +802,7 @@ set_uint (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
   {
     fprintf (stderr,
              _ (
-               "Your input for the '%s' option has to be a non negative number \n"),
+               "Your input for the '%s' option has to be a non negative number\n"),
              option);
     return GNUNET_SYSERR;
   }
@@ -752,15 +817,6 @@ set_uint (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
 }
 
 
-/**
- * Allow user to specify an unsigned integer.
- *
- * @param shortName short name of the option
- * @param name long name of the option
- * @param argumentHelp help text for the option argument
- * @param description long help text for the option
- * @param[out] val set to the value specified at the command line
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_uint (char shortName,
                            const char *name,
@@ -768,13 +824,15 @@ GNUNET_GETOPT_option_uint (char shortName,
                            const char *description,
                            unsigned int *val)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo = { .shortName = shortName,
-                                                 .name = name,
-                                                 .argumentHelp = argumentHelp,
-                                                 .description = description,
-                                                 .require_argument = 1,
-                                                 .processor = &set_uint,
-                                                 .scls = (void *) val };
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = shortName,
+    .name = name,
+    .argumentHelp = argumentHelp,
+    .description = description,
+    .require_argument = 1,
+    .processor = &set_uint,
+    .scls = (void *) val
+  };
 
   return clo;
 }
@@ -793,7 +851,7 @@ GNUNET_GETOPT_option_uint (char shortName,
  * @param value actual value of the option as a string.
  * @return #GNUNET_OK if parsing the value worked
  */
-static int
+static enum GNUNET_GenericReturnValue
 set_uint16 (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
             void *scls,
             const char *option,
@@ -824,15 +882,6 @@ set_uint16 (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
 }
 
 
-/**
- * Allow user to specify an uint16_t.
- *
- * @param shortName short name of the option
- * @param name long name of the option
- * @param argumentHelp help text for the option argument
- * @param description long help text for the option
- * @param[out] val set to the value specified at the command line
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_uint16 (char shortName,
                              const char *name,
@@ -840,13 +889,15 @@ GNUNET_GETOPT_option_uint16 (char shortName,
                              const char *description,
                              uint16_t *val)
 {
-  struct GNUNET_GETOPT_CommandLineOption clo = { .shortName = shortName,
-                                                 .name = name,
-                                                 .argumentHelp = argumentHelp,
-                                                 .description = description,
-                                                 .require_argument = 1,
-                                                 .processor = &set_uint16,
-                                                 .scls = (void *) val };
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = shortName,
+    .name = name,
+    .argumentHelp = argumentHelp,
+    .description = description,
+    .require_argument = 1,
+    .processor = &set_uint16,
+    .scls = (void *) val
+  };
 
   return clo;
 }
@@ -882,7 +933,7 @@ struct Base32Context
  * @param value actual value of the option as a string.
  * @return #GNUNET_OK if parsing the value worked
  */
-static int
+static enum GNUNET_GenericReturnValue
 set_base32 (struct GNUNET_GETOPT_CommandLineProcessorContext *ctx,
             void *scls,
             const char *option,
@@ -920,17 +971,6 @@ free_bc (void *cls)
 }
 
 
-/**
- * Allow user to specify a binary value using Crockford
- * Base32 encoding.
- *
- * @param shortName short name of the option
- * @param name long name of the option
- * @param argumentHelp help text for the option argument
- * @param description long help text for the option
- * @param[out] val binary value decoded from Crockford Base32-encoded argument
- * @param val_size size of @a val in bytes
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_base32_fixed_size (char shortName,
                                         const char *name,
@@ -940,14 +980,16 @@ GNUNET_GETOPT_option_base32_fixed_size (char shortName,
                                         size_t val_size)
 {
   struct Base32Context *bc = GNUNET_new (struct Base32Context);
-  struct GNUNET_GETOPT_CommandLineOption clo = { .shortName = shortName,
-                                                 .name = name,
-                                                 .argumentHelp = argumentHelp,
-                                                 .description = description,
-                                                 .require_argument = 1,
-                                                 .processor = &set_base32,
-                                                 .cleaner = &free_bc,
-                                                 .scls = (void *) bc };
+  struct GNUNET_GETOPT_CommandLineOption clo = {
+    .shortName = shortName,
+    .name = name,
+    .argumentHelp = argumentHelp,
+    .description = description,
+    .require_argument = 1,
+    .processor = &set_base32,
+    .cleaner = &free_bc,
+    .scls = (void *) bc
+  };
 
   bc->val = val;
   bc->val_size = val_size;
@@ -955,12 +997,6 @@ GNUNET_GETOPT_option_base32_fixed_size (char shortName,
 }
 
 
-/**
- * Make the given option mandatory.
- *
- * @param opt option to modify
- * @return @a opt with the mandatory flag set.
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_mandatory (struct GNUNET_GETOPT_CommandLineOption opt)
 {
@@ -969,12 +1005,6 @@ GNUNET_GETOPT_option_mandatory (struct GNUNET_GETOPT_CommandLineOption opt)
 }
 
 
-/**
- * Make the given option mutually exclusive with other options.
- *
- * @param opt option to modify
- * @return @a opt with the exclusive flag set.
- */
 struct GNUNET_GETOPT_CommandLineOption
 GNUNET_GETOPT_option_exclusive (struct GNUNET_GETOPT_CommandLineOption opt)
 {
